:mod:`oujago.utils.time`
========================

.. automodule:: oujago.utils.time


.. autosummary::


Detailed Description
--------------------

.. autofunction:: now
.. autofunction:: today
.. autofunction:: time_format

